[cfe-commits] r94214 - in /cfe/trunk: include/clang/Frontend/PCHBitCodes.h lib/Frontend/PCHReader.cpp lib/Frontend/PCHWriter.cpp

Ted Kremenek kremenek at apple.com
Fri Jan 22 12:59:36 PST 2010


Author: kremenek
Date: Fri Jan 22 14:59:36 2010
New Revision: 94214

URL: http://llvm.org/viewvc/llvm-project?rev=94214&view=rev
Log:
Rename pch::SVN_BRANCH_REVISION to pch::VERSION_CONTROL_BRANCH_REVISION.

Modified:
    cfe/trunk/include/clang/Frontend/PCHBitCodes.h
    cfe/trunk/lib/Frontend/PCHReader.cpp
    cfe/trunk/lib/Frontend/PCHWriter.cpp

Modified: cfe/trunk/include/clang/Frontend/PCHBitCodes.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Frontend/PCHBitCodes.h?rev=94214&r1=94213&r2=94214&view=diff

==============================================================================
--- cfe/trunk/lib/Frontend/PCHReader.cpp (original)
+++ cfe/trunk/lib/Frontend/PCHReader.cpp Fri Jan 22 14:59:36 2010
@@ -1399,7 +1399,7 @@
       NumComments = BlobLen / sizeof(SourceRange);
       break;
         
-    case pch::SVN_BRANCH_REVISION: {
+    case pch::VERSION_CONTROL_BRANCH_REVISION: {
       unsigned CurRevision = getClangSubversionRevision();
       if (Record[0] && CurRevision && Record[0] != CurRevision) {
         Diag(Record[0] < CurRevision? diag::warn_pch_version_too_old

Modified: cfe/trunk/lib/Frontend/PCHWriter.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Frontend/PCHWriter.cpp?rev=94214&r1=94213&r2=94214&view=diff

==============================================================================
--- cfe/trunk/lib/Frontend/PCHWriter.cpp (original)
+++ cfe/trunk/lib/Frontend/PCHWriter.cpp Fri Jan 22 14:59:36 2010
@@ -543,7 +543,7 @@
   RECORD(STAT_CACHE);
   RECORD(EXT_VECTOR_DECLS);
   RECORD(COMMENT_RANGES);
-  RECORD(SVN_BRANCH_REVISION);
+  RECORD(VERSION_CONTROL_BRANCH_REVISION);
   
   // SourceManager Block.
   BLOCK(SOURCE_MANAGER_BLOCK);
@@ -709,12 +709,12 @@
   
   // Subversion branch/version information.
   BitCodeAbbrev *SvnAbbrev = new BitCodeAbbrev();
-  SvnAbbrev->Add(BitCodeAbbrevOp(pch::SVN_BRANCH_REVISION));
+  SvnAbbrev->Add(BitCodeAbbrevOp(pch::VERSION_CONTROL_BRANCH_REVISION));
   SvnAbbrev->Add(BitCodeAbbrevOp(BitCodeAbbrevOp::Fixed, 32)); // SVN revision
   SvnAbbrev->Add(BitCodeAbbrevOp(BitCodeAbbrevOp::Blob)); // SVN branch/tag
   unsigned SvnAbbrevCode = Stream.EmitAbbrev(SvnAbbrev);
   Record.clear();
-  Record.push_back(pch::SVN_BRANCH_REVISION);
+  Record.push_back(pch::VERSION_CONTROL_BRANCH_REVISION);
   Record.push_back(getClangSubversionRevision());
   Stream.EmitRecordWithBlob(SvnAbbrevCode, Record, getClangRepositoryPath());
 }





More information about the cfe-commits mailing list
--- cfe/trunk/include/clang/Frontend/PCHBitCodes.h (original)
+++ cfe/trunk/include/clang/Frontend/PCHBitCodes.h Fri Jan 22 14:59:36 2010
@@ -30,7 +30,7 @@
     /// designed for the previous version could not support reading
     /// the new version), this number should be increased.
     ///
     /// Version 3 of PCH files also requires that the Subversion branch and
     /// revision match exactly, since there is no backward compatibility of
     /// PCH files at this time.
     const unsigned VERSION_MAJOR = 3;
@@ -219,9 +219,9 @@
       /// comments were encountered in the source code.
       COMMENT_RANGES = 20,
       
-      /// \brief Record code for the Subversion branch and revision information
-      /// of the compiler used to build this PCH file.
-      SVN_BRANCH_REVISION = 21
+      /// \brief Record code for the version control branch and revision
+      /// information of the compiler used to build this PCH file.
+      VERSION_CONTROL_BRANCH_REVISION = 21
     };
 
     /// \brief Record types used within a source manager block.
@@ -30,7 +30,7 @@
     /// the new version), this number should be increased.
     ///
-    /// Version 3 of PCH files also requires that the Subversion branch and
+    /// Version 3 of PCH files also requires that the version control branch and
     /// revision match exactly, since there is no backward compatibility of
     /// PCH files at this time.

Modified: cfe/trunk/lib/Frontend/PCHReader.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Frontend/PCHReader.cpp?rev=94214&r1=94213&r2=94214&view=diff

==============================================================================